<?php
/*
 * Mimetyeps for PHP
 * Copyright (c) 2013 JoungKyun.Kim All rights reserved
 * https://cdn.oops.org/mimetypes/
 *
 * Usage:
 * 		(string) MIMES::icon (FILENAME)
 *
 */
Class MIMES {
	static public function extension ($f) {
		$e = preg_replace ('/.*\.([^.]+)$/', '\\1', $f);
		if ( ! $e ) $e = $f;
		return strtolower ($e);
	}
	static public function icon ($f) {
		$iname = self::iconName ($f);
		return '<i class="mimetypes icon-' . $iname . '"></i>';
	}
	private function iconName ($f) {
		$ext = self::extension ($f);
		switch ($ext) {
			case 'ada' : case 'ai' : case 'awk' : case 'c' : case 'cpp' : case 'css' : case 'deb' : case 'docx' : case 'exe' : case 'h' : case 'html' : case 'hwp' : case 'ico' : case 'iso' : case 'jar' : case 'java' : case 'js' : case 'json' : case 'o' : case 'odf' : case 'pas' : case 'pdf' : case 'php' : case 'pl' : case 'pptx' : case 'ps' : case 'psd' : case 'qt' : case 'ra' : case 'rar' : case 'rb' : case 'rpm' : case 'rss' : case 'sh' : case 'sql' : case 'swf' : case 'tar' : case 'tcl' : case 'tex' : case 'torrent' : case 'ttf' : case 'xlsx' : case 'zip' : return $ext;
			case 'ics' : case 'ifb' : return 'cal';
			case 'cs' : return 'csharp';
			case 'com' : case 'bat' : return 'exe';
			case 'cc' : return 'cpp';
			case 'chm' : case 'htm' :
			case 'xhtml' : case 'xhtm' :
			case 'xht' : return 'html';
			case 'class' : case 'jnlp' : case 'pack' : return 'java';
			case 'otf' : case 'odg' : case 'otg' : case 'odi' : case 'oti' : case 'odp' : case 'otp' : case 'ods' : case 'ots' : case 'odt' : case 'odm' : case 'ott' : case 'oth' : return 'odf';
			case 'sig' : case 'p10' : case 'p7m' : case 'p7c' : case 'p7s' : case 'cer' : case 'crl' : return 'pgp';
			case 'phps' : return 'php';
			case 'eps' : return 'ps';
			case 'py' : case 'pyc' : return 'py';
			case 'img' : case 'bin' : return 'iso';
			case 'ram' : case 'rm' : return 'ra';
			case 'mov' : return 'qt';
			case 'bash' : case 'csh' : return 'sh';
			case 'sswf' : case 'ssw' : return 'swf';
			case 'latex' : case 'texinfo' : case 'texi' : return 'tex';
			case 'eot' : case 'woff' : case 'woff2' : return 'ttf';
			case 'gtar' : case 'gz' : case 'tgz' : case 'tga' : return 'tar';
			case 'atom' : case 'cml' : case 'cpl' : case 'opf' : case 'rdf' : case 'rif' : case 'rld' : case 'rl' : case 'rs' : case 'xul' : case 'dtd' : case 'xsl' : case 'xslt' : case 'mxml' : case 'xhvml' : case 'xvml' : case 'xvm' : case 'svg' : case 'svgz' : case 'xml' : return 'xml';
			case 'a' : case 'dll' : case 'so' : return 'o';
			case '7z' : case 'cab' : case 'lzh' : case 'lzh' : case 'bz2' : case 'cpio' : case 'xz' : return 'archive';
			case 'xps' : return 'pdf';
			case 'doc' : case 'docm' : case 'dotm' : case 'dotx' : case 'wcm' : case 'wdb' : case 'wks' : case 'wps' : return 'docx';
			case 'ppt' : case 'mpp' : case 'ppam' : case 'pptm' : case 'sldm' : case 'ppsm' : case 'potm' : case 'sldx' : case 'ppsx' : case 'potx' : return 'pptx';
			case 'xls' : case 'xlam' : case 'xlsb' : case 'xlsm' : case 'xltm' : case 'xltx' : return 'xlsx';
			case 'asx' : case 'dpl' : case 'm3u' : case 'ogx' : case 'pls' : case 'wpl' : case 'ac3' : case 'mms' : case 'mpga' : case 'mp1' : case 'mp2' : case 'mp3' : case 'oga' : case 'ogg' : case 'spx' : case 'mid' : case 'midi' : case 'wma' : case 's3m' : case 'stm' : case 'wav' : return 'audio';
			case 'asf' : case '3gp' : case '3gpp' : case '3g2' : case '3gpp2' : case 'mp4' : case 'mpg4' : case 'mpeg' : case 'mpg' : case 'mpe' : case 'ogv' : case 'mxu' : case 'm4u' : case 'webm' : case 'flv' : case 'wm' : case 'wmv' : case 'wmx' : case 'wvx' : case 'avi' : case 'movie' : return 'movie';
			case 'gif' : case 'jp2' : case 'jpg2' : case 'jpeg' : case 'jpg' : case 'jpe' : case 'jfif' : case 'png' : case 'tiff' : case 'tif' : case 'bmp' : case 'pbm' : case 'xbm' : case 'xpm' : return 'png';
			case 'csv' : case 'asc' : case 'txt' : case 'text' : case 'pm' : case 'el' : case 'hh' : case 'cxx' : case 'hxx' : case 'f90' : case 'sap' : case 'conf' : case 'd' : case 'diff' : case 'dump' : case 'e' : case 'erl' : case 'f' : case 'f90' : case 'for' : case 'gdb' : case 'hs' : case 'inc' : case 'j' : case 'lisp' : case 'jsp' : case 'lua' : case 'm' : case 'q' : case 's' : case 'scheme' : case 'sgm' : case 'spec' : case 'src' : case 'vb' : case 'vim' : case 'xpp' : case 'yaml' : return 'txt';
			default: return 'octet';
		}
	}
}
?>
